//   Copyright 2007, 2008 Nicolas Dubuit
//
//     This file is part of Immix.
//
//     Immix is free software: you can redistribute it and/or modify
//     it under the terms of the GNU General Public License as published by
//     the Free Software Foundation, either version 3 of the License, or
//     (at your option) any later version.
//
//     This program is distributed in the hope that it will be useful,
//     but WITHOUT ANY WARRANTY; without even the implied warranty of
//     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//     GNU General Public License for more details.
//
//     You should have received a copy of the GNU General Public License
//     along with this program.  If not, see <http://www.gnu.org/licenses/>.

#include <QString>
#include <QFileInfo>
#include <iostream>
#include "aligndialog.h"
#include "align.h"


AlignDialog::AlignDialog (int maxi, AlignmentManager*man, QWidget *parent) 
         : QDialog  (parent)
{
    manager=man ;
    max = maxi ;
    setupUi(this) ;
    progressBar->setMaximum (maxi) ;
    progressBar->setMinimum (1) ;
}

void AlignDialog::display(int maxi)
{
    show () ;

    // Set the maximum.
    max = maxi ;
    progressBar->setMaximum (maxi) ;

    // Set up the progress bar.
    progressBar->setFormat (tr("Aligning (%p%)")) ;
    progressBar->setValue (1) ;

    // Make sure the button has the right text.
    cancelButton->setText (tr("&Cancel")) ;

    // Remove all previous items in the table view.
    tableWidget->clearContents () ;
    tableWidget->setRowCount(max-1);
    for (int i=0 ; i<max-1 ; i++)
        tableWidget->setVerticalHeaderItem (i, new QTableWidgetItem("")) ;
}

void AlignDialog::displayAlignmentData (int idx, double dx, double dy, double r, double s)
{
    // Lock mutex to prevent multiple access from differnet working threads.
    mutex.lock () ;

    // Increment progress bar. We can't just setValue(idx) 
    //     as some threads may be faster than others.
    progressBar->setValue (progressBar->value()+1) ;

    // Add data to table.
    QTableWidgetItem* item  ;
    QString fname = QFileInfo(manager->getImagePath(idx)).fileName() ;
    tableWidget->setItem (idx-1, 0, item =new QTableWidgetItem(fname) ) ;
    tableWidget->setItem (idx-1, 1, new QTableWidgetItem(QString::number(dx)) ) ;
    tableWidget->setItem (idx-1, 2, new QTableWidgetItem(QString::number(dy)) ) ;
    tableWidget->setItem (idx-1, 3, new QTableWidgetItem(QString::number(r)) ) ;
    tableWidget->setItem (idx-1, 4, new QTableWidgetItem(QString::number(s)) ) ;
    tableWidget->scrollToItem (item) ;

    // Release mutex.
    mutex.unlock () ;
}

void AlignDialog::finish(void)
{
    // Lock mutex to prevent multiple access from differnet working threads.
    mutex.lock () ;

    // If the "keep" check box is unchecked, close the window.
    if ( ! keepCheckBox->isChecked() )
    {
        hide () ;
    }

    // The progression is finished.
    progressBar->setFormat (tr("Done")) ;

    // Change the text of the dialog
    cancelButton->setText (tr("&Close")) ;

    // Release mutex.
    mutex.unlock () ;
}

